@@ -163,6 +163,12 @@ class VirtualService(BaseKempObject):
         "reversesnihostname",
         "needhostname",
     ]
+    _AFE_PARAMS = [
+        "verify",
+        "compress",
+        "cache",
+        "cachepercent",
+    ]
 
     def __init__(self, loadmaster_info, vs, port=80, prot="tcp",
                  is_sub_vs=False):
@@ -189,6 +195,7 @@ class VirtualService(BaseKempObject):
         self._waf = False
         self._esp = False
         self._ssl = False
+        self._afe = False
 
         if not is_sub_vs:
             # Skip validation when it is a subvs as they do not have ip/port
@@ -243,6 +250,7 @@ class VirtualService(BaseKempObject):
         api = delete_non_existing_parameters(api, self._waf, self._WAF_PARAMS)
         api = delete_non_existing_parameters(api, self._esp, self._ESP_PARAMS)
         api = delete_non_existing_parameters(api, self._ssl, self._SSL_PARAMS)
+        api = delete_non_existing_parameters(api, self._afe, self._AFE_PARAMS)
 
         try:
             if self._is_sub_vs:
@@ -493,12 +501,22 @@ class VirtualService(BaseKempObject):
         else:
             self._esp = True
 
+        # AFE
         self.multiconnect = params.get('MultiConnect', None)
         self.verify = params.get('Verify', None)
         self.compress = params.get('Compress', None)
         self.cache = params.get('Cache', None)
         self.cachepercent = params.get('CachePercent', None)
 
+        if self.verify is not None and int(self.verify) != 0:
+            self._afe = True
+        elif self.compress is not None and self.compress != 'N':
+            self._afe = True
+        elif self.cache is not None and self.cache != 'N':
+            self._afe = True
+        else:
+            self._afe = False
+
         self.sslacceleration = params.get('SSLAcceleration', None)
         self.sslrewrite = params.get('SSLRewrite', None)
         self.sslreverse = params.get('SSLReverse', None)
